@@ -4,7 +4,9 @@ var group__pw__stream =
     [ "pw_buffer", "structpw__buffer.html", [
       [ "buffer", "structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090", null ],
       [ "user_data", "structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96", null ],
-      [ "size", "structpw__buffer.html#a925734b861209896789573f3b94a61c1", null ]
+      [ "size", "structpw__buffer.html#a925734b861209896789573f3b94a61c1", null ],
+      [ "requested", "structpw__buffer.html#ab5fe741ec31686febdbc602098945f08", null ],
+      [ "time", "structpw__buffer.html#a934ea386457a593550c5600368a50994", null ]
     ] ],
     [ "pw_stream_control", "structpw__stream__control.html", [
       [ "flags", "structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2", null ],
@@ -20,7 +22,11 @@ var group__pw__stream =
       [ "rate", "structpw__time.html#a41d793c390eefc6aee165e16e0d7c898", null ],
       [ "ticks", "structpw__time.html#a99e3d7963e24fbf410afa03c73465328", null ],
       [ "delay", "structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7", null ],
-      [ "queued", "structpw__time.html#a91dafbb38397328f8705e2bb20b7625a", null ]
+      [ "queued", "structpw__time.html#a91dafbb38397328f8705e2bb20b7625a", null ],
+      [ "buffered", "structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff", null ],
+      [ "queued_buffers", "structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d", null ],
+      [ "avail_buffers", "structpw__time.html#aebd42745267531bc23e1ee34dd759607", null ],
+      [ "size", "structpw__time.html#ab2eccb212c23d1138aabcdc959c875ff", null ]
     ] ],
     [ "pw_stream_events", "structpw__stream__events.html", [
       [ "version", "structpw__stream__events.html#a74aaca4c31e44dad69aba50607055419", null ],
@@ -37,7 +43,6 @@ var group__pw__stream =
       [ "trigger_done", "structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02", null ]
     ] ],
     [ "pw_stream", "structpw__stream.html", null ],
-    [ "PW_VERSION_STREAM_EVENTS", "group__pw__stream.html#gaf21c1b002f78067d2eca97c455970822", null ],
     [ "pw_stream_state", "group__pw__stream.html#ga9ceaca6fc9acd9a1af080258d763fb82", [
       [ "PW_STREAM_STATE_ERROR", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82aae3c1d061da27957fd3a9389b29ff89e", null ],
       [ "PW_STREAM_STATE_UNCONNECTED", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82aae02f4af09cb65c931e95e1aa3bdd5f3", null ],
@@ -55,8 +60,12 @@ var group__pw__stream =
       [ "PW_STREAM_FLAG_NO_CONVERT", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a87c6bfacd40d4f797505fbc22bd2b9da", null ],
       [ "PW_STREAM_FLAG_EXCLUSIVE", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a79f1bdb249e79c7e71cf46759936768f", null ],
       [ "PW_STREAM_FLAG_DONT_RECONNECT", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab111b3fc3e1d3c1c439a65dc85a3ce20", null ],
-      [ "PW_STREAM_FLAG_ALLOC_BUFFERS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab95a612ea82e3d928b5d2971bcd96465", null ]
+      [ "PW_STREAM_FLAG_ALLOC_BUFFERS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab95a612ea82e3d928b5d2971bcd96465", null ],
+      [ "PW_STREAM_FLAG_TRIGGER", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a8dcfd7b1a9bd963ded7523bc0f01d376", null ],
+      [ "PW_STREAM_FLAG_ASYNC", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a87bea1e205976ef478faed4d9a113576", null ],
+      [ "PW_STREAM_FLAG_EARLY_PROCESS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a1496d5f5dd44faa078d2949463292775", null ]
     ] ],
+    [ "PW_VERSION_STREAM_EVENTS", "group__pw__stream.html#gaf21c1b002f78067d2eca97c455970822", null ],
     [ "pw_stream_state_as_string", "group__pw__stream.html#ga8b023e0bc564e4e8f70cec17e7c608f4", null ],
     [ "pw_stream_new", "group__pw__stream.html#ga712ca485dc634252d144556074980f0a", null ],
     [ "pw_stream_new_simple", "group__pw__stream.html#gacdd761aac33011a41d1f05cfe9effb11", null ],
@@ -70,10 +79,13 @@ var group__pw__stream =
     [ "pw_stream_connect", "group__pw__stream.html#ga0e12176f13e654e64e7f5689e7a6dd54", null ],
     [ "pw_stream_get_node_id", "group__pw__stream.html#ga1744b8f160ac0f8d377db9bfdab57053", null ],
     [ "pw_stream_disconnect", "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30", null ],
-    [ "pw_stream_set_error", "group__pw__stream.html#ga19f542ff2b8a51336ae78cfaec8ed896", null ],
-    [ "pw_stream_update_params", "group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b", null ],
+    [ "pw_stream_set_error", "group__pw__stream.html#ga9f4af21e4ea2691b7d4115fec30a5476", null ],
+    [ "pw_stream_update_params", "group__pw__stream.html#gaace102fde535955faffb8386a2cd3d9c", null ],
+    [ "pw_stream_set_param", "group__pw__stream.html#ga97c613bc4ea822bfbbce0de6ab1b9042", null ],
     [ "pw_stream_get_control", "group__pw__stream.html#ga8a3e7ddb0e61c4266ce735a085adb5e7", null ],
     [ "pw_stream_set_control", "group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52", null ],
+    [ "pw_stream_get_time_n", "group__pw__stream.html#gadde95a60798bfffa6575306bc07ee7f4", null ],
+    [ "pw_stream_get_nsec", "group__pw__stream.html#ga1f3a85c84e2741fe0f664e3ed314d5e4", null ],
     [ "pw_stream_get_time", "group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f", null ],
     [ "pw_stream_dequeue_buffer", "group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94", null ],
     [ "pw_stream_queue_buffer", "group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386", null ],
