@@ -1,16 +1,16 @@
 var group__spa__debug =
 [
-    [ "debug/buffer.h", "debug_2buffer_8h.html", null ],
-    [ "spa/include/spa/debug/context.h", "spa_2include_2spa_2debug_2context_8h.html", null ],
-    [ "debug/dict.h", "debug_2dict_8h.html", null ],
-    [ "debug/format.h", "debug_2format_8h.html", null ],
-    [ "spa/include/spa/debug/log.h", "spa_2include_2spa_2debug_2log_8h.html", null ],
-    [ "spa/include/spa/debug/mem.h", "spa_2include_2spa_2debug_2mem_8h.html", null ],
-    [ "spa/include/spa/debug/node.h", "spa_2include_2spa_2debug_2node_8h.html", null ],
-    [ "debug/pod.h", "debug_2pod_8h.html", null ],
+    [ "buffer.h", "debug_2buffer_8h.html", null ],
+    [ "context.h", "spa_2include_2spa_2debug_2context_8h.html", null ],
+    [ "dict.h", "debug_2dict_8h.html", null ],
+    [ "format.h", "debug_2format_8h.html", null ],
+    [ "log.h", "spa_2include_2spa_2debug_2log_8h.html", null ],
+    [ "mem.h", "spa_2include_2spa_2debug_2mem_8h.html", null ],
+    [ "node.h", "spa_2include_2spa_2debug_2node_8h.html", null ],
+    [ "pod.h", "debug_2pod_8h.html", null ],
     [ "types.h", "types_8h.html", null ],
     [ "spa_debug_context", "structspa__debug__context.html", [
-      [ "log", "structspa__debug__context.html#a5d5a27395a63043da36af7b1289cc711", null ]
+      [ "log", "structspa__debug__context.html#af9f0b4808459f1701213a4dbac14601f", null ]
     ] ],
     [ "spa_debug_log_ctx", "structspa__debug__log__ctx.html", [
       [ "ctx", "structspa__debug__log__ctx.html#a89c265ff2c1860bc78cb3a71e016c44a", null ],
@@ -30,6 +30,7 @@ var group__spa__debug =
     [ "spa_debug_log_pod", "group__spa__debug.html#ga16f96238e59068d1a7637230cb667412", null ],
     [ "spa_debug_log_format", "group__spa__debug.html#ga6f983769067496ffae1b55d9a457384f", null ],
     [ "spa_debug_log_mem", "group__spa__debug.html#gaf6cbda715cf394fce2121122f2f3b9ed", null ],
+    [ "spa_debug_log_dict", "group__spa__debug.html#gae1e8aa2eeedd2ccee01c23637d93fefb", null ],
     [ "spa_debugc_buffer", "group__spa__debug.html#ga95e569a17a18eab8f646974d0b2cc136", null ],
     [ "spa_debug_buffer", "group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139", null ],
     [ "spa_debugc_dict", "group__spa__debug.html#ga6b44755735f4fdcce858fa6f97594b65", null ],
