@@ -122,84 +122,85 @@ var NAVTREEINDEX14 =
 "group__spa__utils.html":[8,6,8],
 "group__spa__utils__defs.html":[8,6,8,1],
 "group__spa__utils__defs.html#ga006941b3f6423cec7b170b4434d8a799":[8,6,8,1,9],
-"group__spa__utils__defs.html#ga007f98725701a4b6debe365c7a5e0bbe":[8,6,8,1,84],
-"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84":[8,6,8,1,58],
+"group__spa__utils__defs.html#ga007f98725701a4b6debe365c7a5e0bbe":[8,6,8,1,85],
+"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84":[8,6,8,1,59],
 "group__spa__utils__defs.html#ga06647c110a0382a09bea681a14634f64":[8,6,8,1,21],
-"group__spa__utils__defs.html#ga0fb5b0492ff8bb640cbad9b2711c77d0":[8,6,8,1,66],
+"group__spa__utils__defs.html#ga0fb5b0492ff8bb640cbad9b2711c77d0":[8,6,8,1,67],
 "group__spa__utils__defs.html#ga1179685eef5a041a5c8e60a9a6483048":[8,6,8,1,27],
-"group__spa__utils__defs.html#ga1b605788d4782d77eb54b75f258413b9":[8,6,8,1,38],
-"group__spa__utils__defs.html#ga1f57dfee056b657ddcd2bc69a7f45bce":[8,6,8,1,57],
-"group__spa__utils__defs.html#ga2157cfb3de1793302e5d08958bdc8ab2":[8,6,8,1,73],
-"group__spa__utils__defs.html#ga26f69327ba25a67c5120805511190740":[8,6,8,1,67],
-"group__spa__utils__defs.html#ga2c939bee0863eddd75b264b2aaf316e0":[8,6,8,1,62],
+"group__spa__utils__defs.html#ga1b605788d4782d77eb54b75f258413b9":[8,6,8,1,39],
+"group__spa__utils__defs.html#ga1f57dfee056b657ddcd2bc69a7f45bce":[8,6,8,1,58],
+"group__spa__utils__defs.html#ga2157cfb3de1793302e5d08958bdc8ab2":[8,6,8,1,74],
+"group__spa__utils__defs.html#ga26f69327ba25a67c5120805511190740":[8,6,8,1,68],
+"group__spa__utils__defs.html#ga2c939bee0863eddd75b264b2aaf316e0":[8,6,8,1,63],
 "group__spa__utils__defs.html#ga33e30c1bdbba747c8c00077913d48411":[8,6,8,1,23],
-"group__spa__utils__defs.html#ga3404aa33acd9e8316fb33ebd146446f0":[8,6,8,1,65],
+"group__spa__utils__defs.html#ga3404aa33acd9e8316fb33ebd146446f0":[8,6,8,1,66],
 "group__spa__utils__defs.html#ga34890f84380ed041625fc0a252186bf2":[8,6,8,1,24],
-"group__spa__utils__defs.html#ga3625c72ccb164919faaf2a3c5a37e9c2":[8,6,8,1,81],
+"group__spa__utils__defs.html#ga3625c72ccb164919faaf2a3c5a37e9c2":[8,6,8,1,82],
 "group__spa__utils__defs.html#ga3bca1a11d1c7e8404f9456580acf0676":[8,6,8,1,11],
-"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[8,6,8,1,48],
-"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[8,6,8,1,60],
-"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[8,6,8,1,76],
-"group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[8,6,8,1,69],
-"group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[8,6,8,1,45],
+"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[8,6,8,1,49],
+"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[8,6,8,1,61],
+"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[8,6,8,1,77],
+"group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[8,6,8,1,70],
+"group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[8,6,8,1,46],
 "group__spa__utils__defs.html#ga57aec3d89182594c8fef7be284f41fff":[8,6,8,1,12],
 "group__spa__utils__defs.html#ga58dddf4d57e29beade3b44e156dea532":[8,6,8,1,16],
-"group__spa__utils__defs.html#ga59196e4cfb0d8c0a8bdcd909cbbea334":[8,6,8,1,29],
-"group__spa__utils__defs.html#ga5b82642b5708ab665c9204338b6cd0e2":[8,6,8,1,63],
-"group__spa__utils__defs.html#ga5e46f399b745cda80c6a5a8ab8d5d14f":[8,6,8,1,31],
-"group__spa__utils__defs.html#ga6212956dcff36c69fa954f66efaefbcf":[8,6,8,1,79],
-"group__spa__utils__defs.html#ga6259b69a24b203050fe69cacac57748a":[8,6,8,1,42],
-"group__spa__utils__defs.html#ga632087e970399228667a768ba8424f4e":[8,6,8,1,75],
-"group__spa__utils__defs.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0":[8,6,8,1,43],
-"group__spa__utils__defs.html#ga6c3f9f95123f53da37d2bd173bd17ed1":[8,6,8,1,40],
+"group__spa__utils__defs.html#ga59196e4cfb0d8c0a8bdcd909cbbea334":[8,6,8,1,30],
+"group__spa__utils__defs.html#ga5b82642b5708ab665c9204338b6cd0e2":[8,6,8,1,64],
+"group__spa__utils__defs.html#ga5e46f399b745cda80c6a5a8ab8d5d14f":[8,6,8,1,32],
+"group__spa__utils__defs.html#ga6212956dcff36c69fa954f66efaefbcf":[8,6,8,1,80],
+"group__spa__utils__defs.html#ga6259b69a24b203050fe69cacac57748a":[8,6,8,1,43],
+"group__spa__utils__defs.html#ga632087e970399228667a768ba8424f4e":[8,6,8,1,76],
+"group__spa__utils__defs.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0":[8,6,8,1,44],
+"group__spa__utils__defs.html#ga6c3f9f95123f53da37d2bd173bd17ed1":[8,6,8,1,41],
 "group__spa__utils__defs.html#ga796e3d4570d8d539ea5886074a646a11":[8,6,8,1,17],
-"group__spa__utils__defs.html#ga7b184a799c7168d95deaecab5208f557":[8,6,8,1,49],
-"group__spa__utils__defs.html#ga7b3174639eb92d4c045a2bbc72a035df":[8,6,8,1,41],
+"group__spa__utils__defs.html#ga7b184a799c7168d95deaecab5208f557":[8,6,8,1,50],
+"group__spa__utils__defs.html#ga7b3174639eb92d4c045a2bbc72a035df":[8,6,8,1,42],
 "group__spa__utils__defs.html#ga7f23cca5e034297bbd1b6860d1dbfdbc":[8,6,8,1,26],
 "group__spa__utils__defs.html#ga895eccfd8032e0e9eec102e3b8442f12":[8,6,8,1,18],
-"group__spa__utils__defs.html#ga933e7dba5e09dd618617b7b16c0d42fc":[8,6,8,1,54],
-"group__spa__utils__defs.html#ga9a615b131c891caac9a73e05b35da09c":[8,6,8,1,70],
+"group__spa__utils__defs.html#ga933e7dba5e09dd618617b7b16c0d42fc":[8,6,8,1,55],
+"group__spa__utils__defs.html#ga9444bfd2adb1312894e2c2991e752ae4":[8,6,8,1,28],
+"group__spa__utils__defs.html#ga9a615b131c891caac9a73e05b35da09c":[8,6,8,1,71],
 "group__spa__utils__defs.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1":[8,6,8,1,5],
-"group__spa__utils__defs.html#gaa360562916c7e9ab66865f277477f4e6":[8,6,8,1,74],
-"group__spa__utils__defs.html#gaa3a2b836ca54d95f207f5557988db748":[8,6,8,1,72],
+"group__spa__utils__defs.html#gaa360562916c7e9ab66865f277477f4e6":[8,6,8,1,75],
+"group__spa__utils__defs.html#gaa3a2b836ca54d95f207f5557988db748":[8,6,8,1,73],
 "group__spa__utils__defs.html#gaa44a69e371d934ab026ae08af1d9b67e":[8,6,8,1,8],
-"group__spa__utils__defs.html#gaa495b586c261831b67f09c7f9851aa05":[8,6,8,1,32],
-"group__spa__utils__defs.html#gaa92b4913ce779aa401cc714ae829eace":[8,6,8,1,36],
+"group__spa__utils__defs.html#gaa495b586c261831b67f09c7f9851aa05":[8,6,8,1,33],
+"group__spa__utils__defs.html#gaa92b4913ce779aa401cc714ae829eace":[8,6,8,1,37],
 "group__spa__utils__defs.html#gaaa953e4f238a81e2ae649dc243cc70b4":[8,6,8,1,25],
-"group__spa__utils__defs.html#gaabdb5fd45bca56878896d7c28204fb88":[8,6,8,1,39],
-"group__spa__utils__defs.html#gaad6949f0b0a59d29fdf35ff11ebf83cb":[8,6,8,1,30],
-"group__spa__utils__defs.html#gab30712bed8289c9218eb66d9bfeeab78":[8,6,8,1,51],
-"group__spa__utils__defs.html#gab4c957beedd4012fd0513f174d7b8b1a":[8,6,8,1,68],
-"group__spa__utils__defs.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca":[8,6,8,1,64],
-"group__spa__utils__defs.html#gac1ac8f034b73e453c531d928cdfdd8b7":[8,6,8,1,55],
-"group__spa__utils__defs.html#gac30327f8b5e6a9c6f9129a73581d09dc":[8,6,8,1,71],
-"group__spa__utils__defs.html#gac8080acabcd35c560a15df5e1801afa1":[8,6,8,1,34],
-"group__spa__utils__defs.html#gac894bd2d39b2644e1bacf4b11c0a187d":[8,6,8,1,53],
-"group__spa__utils__defs.html#gac8965bea56eb75da08e84a547bee992e":[8,6,8,1,52],
+"group__spa__utils__defs.html#gaabdb5fd45bca56878896d7c28204fb88":[8,6,8,1,40],
+"group__spa__utils__defs.html#gaad6949f0b0a59d29fdf35ff11ebf83cb":[8,6,8,1,31],
+"group__spa__utils__defs.html#gab30712bed8289c9218eb66d9bfeeab78":[8,6,8,1,52],
+"group__spa__utils__defs.html#gab4c957beedd4012fd0513f174d7b8b1a":[8,6,8,1,69],
+"group__spa__utils__defs.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca":[8,6,8,1,65],
+"group__spa__utils__defs.html#gac1ac8f034b73e453c531d928cdfdd8b7":[8,6,8,1,56],
+"group__spa__utils__defs.html#gac30327f8b5e6a9c6f9129a73581d09dc":[8,6,8,1,72],
+"group__spa__utils__defs.html#gac8080acabcd35c560a15df5e1801afa1":[8,6,8,1,35],
+"group__spa__utils__defs.html#gac894bd2d39b2644e1bacf4b11c0a187d":[8,6,8,1,54],
+"group__spa__utils__defs.html#gac8965bea56eb75da08e84a547bee992e":[8,6,8,1,53],
 "group__spa__utils__defs.html#gacbdd2b8d9e9137bbbd9a38f495c80263":[8,6,8,1,6],
-"group__spa__utils__defs.html#gacc9914448bc9fd68ae5ccf004c401bcb":[8,6,8,1,46],
+"group__spa__utils__defs.html#gacc9914448bc9fd68ae5ccf004c401bcb":[8,6,8,1,47],
 "group__spa__utils__defs.html#gace48f5bc6836a62c328fcac938f8ea6e":[8,6,8,1,15],
 "group__spa__utils__defs.html#gaceee1eb1469c2ab68034f5619913bc0d":[8,6,8,1,10],
-"group__spa__utils__defs.html#gad485e752b9b897f6434724f669ba72ae":[8,6,8,1,56],
-"group__spa__utils__defs.html#gad5b23b2094b330aacd6489da1c8fa7b7":[8,6,8,1,47],
-"group__spa__utils__defs.html#gadc0cd747e27d01b74cdd6d3131e3df27":[8,6,8,1,61],
-"group__spa__utils__defs.html#gadd03b1b1f299d9249de66ff32bc34569":[8,6,8,1,82],
+"group__spa__utils__defs.html#gad485e752b9b897f6434724f669ba72ae":[8,6,8,1,57],
+"group__spa__utils__defs.html#gad5b23b2094b330aacd6489da1c8fa7b7":[8,6,8,1,48],
+"group__spa__utils__defs.html#gadc0cd747e27d01b74cdd6d3131e3df27":[8,6,8,1,62],
+"group__spa__utils__defs.html#gadd03b1b1f299d9249de66ff32bc34569":[8,6,8,1,83],
 "group__spa__utils__defs.html#gae1bb114e5bb79da44be5c26e7a9bf6e1":[8,6,8,1,19],
-"group__spa__utils__defs.html#gae2c26bfcbc2a33bcfae86018b35fab20":[8,6,8,1,80],
-"group__spa__utils__defs.html#gae8ab0b793d870a9725897e695454c12b":[8,6,8,1,28],
-"group__spa__utils__defs.html#gae8d35b670e70b6cdba489ca76b5791d4":[8,6,8,1,77],
-"group__spa__utils__defs.html#gaec22d2ead4ec1771760219dc16f24709":[8,6,8,1,33],
+"group__spa__utils__defs.html#gae2c26bfcbc2a33bcfae86018b35fab20":[8,6,8,1,81],
+"group__spa__utils__defs.html#gae8ab0b793d870a9725897e695454c12b":[8,6,8,1,29],
+"group__spa__utils__defs.html#gae8d35b670e70b6cdba489ca76b5791d4":[8,6,8,1,78],
+"group__spa__utils__defs.html#gaec22d2ead4ec1771760219dc16f24709":[8,6,8,1,34],
 "group__spa__utils__defs.html#gaf296ce57d6de2645675d2c89fdc8af0a":[8,6,8,1,7],
 "group__spa__utils__defs.html#gaf42b2cfc208dc17d25624d84f962b25d":[8,6,8,1,14],
 "group__spa__utils__defs.html#gaf5c3a152070995c325caaaf0333269c0":[8,6,8,1,20],
-"group__spa__utils__defs.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e":[8,6,8,1,83],
-"group__spa__utils__defs.html#gaf88c39fbcce246ddc0e78a934dda87cb":[8,6,8,1,59],
-"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[8,6,8,1,37],
-"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[8,6,8,1,44],
-"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[8,6,8,1,78],
-"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[8,6,8,1,35],
+"group__spa__utils__defs.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e":[8,6,8,1,84],
+"group__spa__utils__defs.html#gaf88c39fbcce246ddc0e78a934dda87cb":[8,6,8,1,60],
+"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[8,6,8,1,38],
+"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[8,6,8,1,45],
+"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[8,6,8,1,79],
+"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[8,6,8,1,36],
 "group__spa__utils__defs.html#gafd41067bab5e0c66b38886f672702dd4":[8,6,8,1,22],
-"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[8,6,8,1,50],
+"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[8,6,8,1,51],
 "group__spa__utils__defs.html#gafdd52836cf3dfdc12328615ac44c18e0":[8,6,8,1,13],
 "group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[8,6,8,1,5,0],
 "group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[8,6,8,1,5,1],
@@ -248,6 +249,5 @@ var NAVTREEINDEX14 =
 "node_2event_8h.html":[8,6,6,1],
 "node_2type-info_8h.html":[8,6,6,5],
 "page_access.html":[5,2],
-"page_api.html":[6],
-"page_audio.html":[5,1]
+"page_api.html":[6]
 };
