@@ -1,5 +1,6 @@
 var NAVTREEINDEX15 =
 {
+"page_audio.html":[5,1],
 "page_client_impl.html":[6,1],
 "page_client_impl.html#sec_page_client_impl_credentials":[6,1,1],
 "page_client_impl.html#sec_page_client_impl_overview":[6,1,0],
@@ -248,6 +249,5 @@ var NAVTREEINDEX15 =
 "protocol-native_8h.html":[8,5,3,0],
 "protocol_8h.html":[8,3,13,0],
 "proxy_8h.html":[8,2,13,0],
-"resource_8h.html":[8,3,14,0],
-"result_8h.html":[8,6,8,10,0]
+"resource_8h.html":[8,3,14,0]
 };
