@@ -1,5 +1,6 @@
 var NAVTREEINDEX17 =
 {
+"structpw__endpoint__stream__methods.html#a06d4d4c207f88dd3e87dadee7401b785":[8,5,4,15,1],
 "structpw__endpoint__stream__methods.html#a795f1ab22b0899bc18142419723e369b":[8,5,4,15,4],
 "structpw__endpoint__stream__methods.html#ab73e2f70fc5a78721ebb38118af947b5":[8,5,4,15,0],
 "structpw__endpoint__stream__methods.html#ab7b9c94de60336876dac12fbd671e8cb":[8,5,4,15,3],
@@ -39,8 +40,8 @@ var NAVTREEINDEX17 =
 "structpw__global__events.html#a8ccd4e331a4c1a0401e13ab3c9b04236":[8,3,12,1,1],
 "structpw__global__events.html#a909a601dfd3ce02c04c0e714df6450a1":[8,3,12,1,0],
 "structpw__global__events.html#a914924700d817cb9d4f58c327d5952e8":[8,3,12,1,3],
-"structpw__impl__client.html":[8,3,0,2],
 "structpw__impl__client.html":[8,2,2,5],
+"structpw__impl__client.html":[8,3,0,2],
 "structpw__impl__client__events.html":[8,3,0,1],
 "structpw__impl__client__events.html#a046e956441b5395308c8ff140292dfee":[8,3,0,1,7],
 "structpw__impl__client__events.html#a30be6d32c40038f0ae9dfdbccdf74e1b":[8,3,0,1,0],
@@ -95,8 +96,8 @@ var NAVTREEINDEX17 =
 "structpw__impl__module__events.html#a4cfcceec669bbbdf6697e36cd5dbae1d":[8,3,6,1,1],
 "structpw__impl__module__events.html#a75c9588d21472e8d610b813bdd9a419e":[8,3,6,1,4],
 "structpw__impl__module__events.html#aea5e86ba050b1b9e92bb3c7ba3425f71":[8,3,6,1,0],
-"structpw__impl__node.html":[8,3,7,3],
 "structpw__impl__node.html":[8,2,2,6],
+"structpw__impl__node.html":[8,3,7,3],
 "structpw__impl__node__events.html":[8,3,7,1],
 "structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18":[8,3,7,1,16],
 "structpw__impl__node__events.html#a16b71cb7eece2a1b7b2d89007357238b":[8,3,7,1,10],
@@ -122,9 +123,9 @@ var NAVTREEINDEX17 =
 "structpw__impl__node__rt__events.html#ab0476813d8e72d032e97e1c132b875e5":[8,3,7,2,3],
 "structpw__impl__node__rt__events.html#aba356d5c2194a4865a6fa46c760f4ccd":[8,3,7,2,1],
 "structpw__impl__node__rt__events.html#af626e58811dda76480d91b4cfc242f71":[8,3,7,2,0],
+"structpw__impl__port.html":[8,3,4,3],
 "structpw__impl__port.html":[8,3,7,4],
 "structpw__impl__port.html":[8,3,8,2],
-"structpw__impl__port.html":[8,3,4,3],
 "structpw__impl__port__events.html":[8,3,8,1],
 "structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82":[8,3,8,1,8],
 "structpw__impl__port__events.html#a5595c734ed5c3fc9ab27c2f5244fa325":[8,3,8,1,1],
@@ -248,6 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__port__info.html":[8,2,12,1],
 "structpw__port__info.html#a3c95bbed7080e2f033b133409315f31a":[8,2,12,1,4],
 "structpw__port__info.html#a5131d23e86aef3c0d1727a6aa6359e9c":[8,2,12,1,3],
-"structpw__port__info.html#a59e2afe4f65b5f74eb7a28f51fb958aa":[8,2,12,1,2],
-"structpw__port__info.html#ab8bd7cf30a25d379e02bfc66c5692c64":[8,2,12,1,0]
+"structpw__port__info.html#a59e2afe4f65b5f74eb7a28f51fb958aa":[8,2,12,1,2]
 };
