@@ -1,5 +1,7 @@
 var NAVTREEINDEX19 =
 {
+"structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[8,6,1,7,0],
+"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[8,6,1,7,2],
 "structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560":[8,6,1,7,3],
 "structspa__buffer.html#adbf5510ef0707e22b19980c84b61a073":[8,6,1,7,1],
 "structspa__buffer__alloc__info.html":[8,6,1,4],
@@ -247,7 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__io__segment__video.html#a4f9acf42fec13d66072ac47ca9aad116":[8,6,6,14,5],
 "structspa__io__segment__video.html#a500d2d64d490ad483be879cb40b799b4":[8,6,6,14,2],
 "structspa__io__segment__video.html#a9c45645d7e6aa9aea4508336dd87d17d":[8,6,6,14,7],
-"structspa__io__segment__video.html#abb72f2853693bb3cfad27520b41f3248":[8,6,6,14,0],
-"structspa__io__segment__video.html#ad9a1cecce33ac8e1c02532188fe51b5f":[8,6,6,14,3],
-"structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db":[8,6,6,14,4]
+"structspa__io__segment__video.html#abb72f2853693bb3cfad27520b41f3248":[8,6,6,14,0]
 };
