@@ -1,5 +1,6 @@
 var NAVTREEINDEX20 =
 {
+"structspa__io__segment__video.html#ad9a1cecce33ac8e1c02532188fe51b5f":[8,6,6,14,3],
 "structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db":[8,6,6,14,4],
 "structspa__io__segment__video.html#ae03652e1ab2e76a1a03a63d7bd0fcc99":[8,6,6,14,8],
 "structspa__io__segment__video.html#ae1cc1d15b524665254cff4c3d5daeceb":[8,6,6,14,6],
@@ -248,6 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__pod__parser__state.html#a7d20db21de9472df961d8b2da5845ea0":[8,6,0,17,0],
 "structspa__pod__parser__state.html#a88566be69781e492f2927a83429d0d28":[8,6,0,17,1],
 "structspa__pod__parser__state.html#acf6a430c72bd19259ecbda4643d4b2cf":[8,6,0,17,2],
-"structspa__pod__pointer.html":[8,6,0,39],
-"structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7":[8,6,0,39,1]
+"structspa__pod__pointer.html":[8,6,0,39]
 };
