@@ -1,5 +1,6 @@
 var NAVTREEINDEX6 =
 {
+"group__spa__buffer.html#gaeaf6a23eedc8287e462151c68cf392d8":[8,6,1,35],
 "group__spa__buffer.html#gaebb70d9cbd7c2ae9cd782216dbb51fb6":[8,6,1,48],
 "group__spa__buffer.html#gaec7e50ee77e4bd008354c43ba865b34b":[8,6,1,21],
 "group__spa__buffer.html#gafb4a59d5cb75403df44c507e7cb53d8c":[8,6,1,44],
@@ -248,6 +249,5 @@ var NAVTREEINDEX6 =
 "group__spa__graph.html#ga234972c464dadf002ac0c7fb12683668":[8,6,5,32],
 "group__spa__graph.html#ga258938261c43d11f61333a77be0a3324":[8,6,5,21],
 "group__spa__graph.html#ga277f9def5e8ae6b1348c4d64ebd2c922":[8,6,5,28],
-"group__spa__graph.html#ga28ea8a94abe2994c203feb04333e2981":[8,6,5,36],
-"group__spa__graph.html#ga35411dc23f99354fb70e3c298426da7a":[8,6,5,8]
+"group__spa__graph.html#ga28ea8a94abe2994c203feb04333e2981":[8,6,5,36]
 };
