@@ -3,11 +3,11 @@ var searchData=
   ['main_20loop_0',['Main Loop',['../group__pw__main__loop.html',1,'']]],
   ['main_2dloop_2eh_1',['main-loop.h',['../main-loop_8h.html',1,'']]],
   ['making_20a_20connection_2',['Making a connection',['../page_native_protocol.html#native-protocol-making-connection',1,'']]],
-  ['manager_3',['Netjack2 manager',['../page_module_netjack2_manager.html',1,'page_modules']]],
-  ['manager_4',['Manager',['../page_session_manager.html',1,'PipeWire Session Manager'],['../group__pw__session__manager.html',1,'Session Manager'],['../page_module_session_manager.html',1,'Session Manager']]],
+  ['manager_3',['Manager',['../page_session_manager.html',1,'PipeWire Session Manager'],['../group__pw__session__manager.html',1,'Session Manager'],['../page_module_session_manager.html',1,'Session Manager']]],
+  ['manager_4',['Netjack2 manager',['../page_module_netjack2_manager.html',1,'page_modules']]],
   ['manager_20properties_5',['Session Manager Properties',['../page_man_pipewire-client_conf_5.html#client_conf__session_manager_properties',1,'']]],
-  ['map_6',['map',['../structpw__memblock.html#ae9876a344086ff407cf6bf3704b24515',1,'pw_memblock']]],
-  ['map_7',['Map',['../group__pw__map.html',1,'']]],
+  ['map_6',['Map',['../group__pw__map.html',1,'']]],
+  ['map_7',['map',['../structpw__memblock.html#ae9876a344086ff407cf6bf3704b24515',1,'pw_memblock']]],
   ['map_2eh_8',['map.h',['../map_8h.html',1,'']]],
   ['mapoffset_9',['mapoffset',['../structspa__data.html#a75b63dcf6ea09c5908b8682f1696eeae',1,'spa_data']]],
   ['mask_10',['mask',['../structspa__source.html#ad43d6b5fd83f3e86be4f6103009370cd',1,'spa_source']]],
@@ -58,17 +58,14 @@ var searchData=
   ['module_55',['Module',['../group__pw__module.html',1,'']]],
   ['module_20impl_56',['Module Impl',['../group__pw__impl__module.html',1,'']]],
   ['module_2eh_57',['module.h',['../module_8h.html',1,'']]],
-  ['modules_58',['libpipewire-modules',['../page_man_libpipewire-modules_7.html',1,'page_config']]],
-  ['modules_59',['Modules',['../page_modules.html',1,'']]],
-  ['modules_60',['MODULES',['../page_man_pipewire_conf_5.html#pipewire_conf__modules',1,'']]],
-  ['modules_61',['pipewire-pulse-modules',['../page_man_pipewire-pulse-modules_7.html',1,'page_config']]],
-  ['modules_62',['Pulseaudio Modules',['../page_pulse_modules.html',1,'']]],
-  ['modules_63',['PULSEAUDIO MODULES',['../page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_modules',1,'']]],
-  ['mon_64',['pw-mon',['../page_man_pw-mon_1.html',1,'page_programs']]],
-  ['monitor_65',['spa-monitor',['../page_man_spa-monitor_1.html',1,'page_programs']]],
-  ['mp3_66',['mp3',['../structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b',1,'spa_audio_info']]],
-  ['mp3_2dutils_2eh_67',['mp3-utils.h',['../mp3-utils_8h.html',1,'']]],
-  ['multiview_2eh_68',['multiview.h',['../multiview_8h.html',1,'']]],
-  ['multiview_5fflags_69',['multiview_flags',['../structspa__video__info__raw.html#a99a7b7e3ccd534510cb33036028edd7e',1,'spa_video_info_raw']]],
-  ['multiview_5fmode_70',['multiview_mode',['../structspa__video__info__raw.html#a48a1b5480465ffdcee2dfa9e95ed47fb',1,'spa_video_info_raw']]]
+  ['modules_58',['MODULES',['../page_man_pipewire_conf_5.html#pipewire_conf__modules',1,'MODULES'],['../page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_modules',1,'PULSEAUDIO MODULES']]],
+  ['modules_59',['Modules',['../page_modules.html',1,'Modules'],['../page_pulse_modules.html',1,'Pulseaudio Modules']]],
+  ['modules_60',['modules',['../page_man_libpipewire-modules_7.html',1,'libpipewire-modules'],['../page_man_pipewire-pulse-modules_7.html',1,'pipewire-pulse-modules']]],
+  ['mon_61',['pw-mon',['../page_man_pw-mon_1.html',1,'page_programs']]],
+  ['monitor_62',['spa-monitor',['../page_man_spa-monitor_1.html',1,'page_programs']]],
+  ['mp3_63',['mp3',['../structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b',1,'spa_audio_info']]],
+  ['mp3_2dutils_2eh_64',['mp3-utils.h',['../mp3-utils_8h.html',1,'']]],
+  ['multiview_2eh_65',['multiview.h',['../multiview_8h.html',1,'']]],
+  ['multiview_5fflags_66',['multiview_flags',['../structspa__video__info__raw.html#a99a7b7e3ccd534510cb33036028edd7e',1,'spa_video_info_raw']]],
+  ['multiview_5fmode_67',['multiview_mode',['../structspa__video__info__raw.html#a48a1b5480465ffdcee2dfa9e95ed47fb',1,'spa_video_info_raw']]]
 ];
