@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['echo_20cancel_0',['echo cancel',['../page_module_echo_cancel.html',1,'Echo Cancel'],['../page_pulse_module_echo_cancel.html',1,'Echo Cancel']]],
+  ['echo_20cancel_0',['Echo Cancel',['../page_module_echo_cancel.html',1,'Echo Cancel'],['../page_pulse_module_echo_cancel.html',1,'Echo Cancel']]],
   ['enumerating_20objects_1',['Tutorial - Part 2: Enumerating Objects',['../page_tutorial2.html',1,'page_tutorial']]],
   ['example_20filter_2',['Example Filter',['../page_module_example_filter.html',1,'page_modules']]],
   ['example_20programs_3',['List of example programs',['../page_examples.html',1,'page_tutorial']]],
